@@ -1,9 +1,7 @@
 from .argument_parser import ArgumentParser
-from .command_parser import CommandParser
 from .docstring_parser import DocStringParser
 
 __all__ = [
     "ArgumentParser",
-    "CommandParser",
     "DocStringParser",
 ]
