@@ -24,6 +24,10 @@ class ArgumentPreprocessor:
 
     def __init__(self, command_tree: CommandTree, target_class: type | None = None):
         """Initialize the preprocessor with command tree and target class info."""
+        # Guard: Ensure command_tree is not None
+        if command_tree is None:
+            raise ValueError("command_tree cannot be None")
+        
         self.command_tree = command_tree
         self.target_class = target_class
         self._global_options: set[str] = set()
@@ -37,6 +41,10 @@ class ArgumentPreprocessor:
 
     def validate_arguments(self, args: list[str]) -> tuple[bool, list[str]]:
         """Validate arguments before preprocessing."""
+        # Guard: Ensure args is not None
+        if args is None:
+            raise ValueError("args cannot be None")
+        
         errors = []
 
         # Basic validation - check for obviously malformed arguments
@@ -56,6 +64,10 @@ class ArgumentPreprocessor:
 
     def preprocess_args(self, args: list[str]) -> list[str]:
         """Reorder arguments to match argparse hierarchical expectations."""
+        # Guard: Ensure args is not None
+        if args is None:
+            raise ValueError("args cannot be None")
+        
         # Parse command structure from positional arguments
         command_path = self._extract_command_path(args)
 
@@ -132,6 +144,10 @@ class ArgumentPreprocessor:
 
     def _extract_constructor_options(self, cls: type, skip_params: int = 1) -> set[str]:
         """Extract options from class constructor."""
+        # Guard: Ensure cls is not None
+        if cls is None:
+            raise ValueError("cls cannot be None")
+        
         options: set[str] = set()
         if not hasattr(cls, "__init__"):
             return options
@@ -151,6 +167,10 @@ class ArgumentPreprocessor:
 
     def _extract_function_options(self, func: Any) -> set[str]:
         """Extract options from function signature."""
+        # Guard: Ensure func is not None
+        if func is None:
+            raise ValueError("func cannot be None")
+        
         options = set()
         sig = inspect.signature(func)
 
@@ -169,6 +189,10 @@ class ArgumentPreprocessor:
 
     def _extract_positional_parameter(self, func: Any) -> PositionalInfo | None:
         """Extract positional parameter info from function signature."""
+        # Guard: Ensure func is not None
+        if func is None:
+            raise ValueError("func cannot be None")
+        
         sig = inspect.signature(func)
         _, param_help = DocStringParser.extract_function_help(func)
 
@@ -178,17 +202,28 @@ class ArgumentPreprocessor:
 
             # First parameter without default value becomes positional
             if param.default == param.empty:
+                help_text = DocStringParser.create_parameter_help(
+                    param_name, param_help, param.annotation, param.default
+                )
                 return PositionalInfo(
                     param_name=param_name,
                     param_type=param.annotation if param.annotation != param.empty else str,
                     is_required=True,
-                    help_text=param_help.get(param_name),
+                    help_text=help_text,
                 )
 
         return None
 
     def _is_first_non_default_param(self, func: Any, param_name: str) -> bool:
         """Check if this is the first parameter without a default value."""
+        # Guard: Ensure func is not None
+        if func is None:
+            raise ValueError("func cannot be None")
+        
+        # Guard: Ensure param_name is not None
+        if param_name is None:
+            raise ValueError("param_name cannot be None")
+        
         sig = inspect.signature(func)
 
         for name, param in sig.parameters.items():
