@@ -4,7 +4,7 @@ import inspect
 from typing import Any
 
 from freyja.utils.text_util import TextUtil
-
+from .docstring_parser import DocStringParser
 from .argument_preprocessor import PositionalInfo
 
 
@@ -85,7 +85,7 @@ class OptionDiscovery:
 
         return positional_params
 
-    def get_all_known_options(self, command_path: list[str] = None) -> set[str]:
+    def get_all_known_options(self, command_path: list[str] | None = None) -> set[str]:
         """Get all known options for a given command path."""
         all_options = set()
 
@@ -184,11 +184,17 @@ class OptionDiscovery:
                     continue
                 # First parameter without default becomes positional
                 if param.default == param.empty:
+                    # Get help text from function docstring
+                    _, param_help = DocStringParser.extract_function_help(function)
+                    help_text = DocStringParser.create_parameter_help(
+                        param_name, param_help, param.annotation, param.default
+                    )
+                    
                     return PositionalInfo(
                         param_name=param_name,
                         param_type=param.annotation if param.annotation != param.empty else str,
                         is_required=True,
-                        help_text=f"{param_name} parameter",
+                        help_text=help_text,
                     )
         except (ValueError, TypeError):
             # Handle cases where signature inspection fails
@@ -236,7 +242,7 @@ class OptionDiscovery:
         return conflicts
 
     def suggest_option_corrections(
-        self, unknown_option: str, command_path: list[str] = None
+        self, unknown_option: str, command_path: list[str] | None = None
     ) -> list[str]:
         """Suggest corrections for unknown options using similarity matching."""
         all_options = self.get_all_known_options(command_path)
