@@ -4,7 +4,7 @@ import inspect
 from typing import Any
 
 from freyja.utils.text_util import TextUtil
-
+from .docstring_parser import DocStringParser
 from .argument_preprocessor import PositionalInfo
 
 
@@ -13,12 +13,23 @@ class PositionalHandler:
 
     def __init__(self, positional_info: dict[str, PositionalInfo]):
         """Initialize positional handler with discovered positional parameters."""
+        # Guard: Ensure positional_info is not None
+        if positional_info is None:
+            raise ValueError("positional_info cannot be None")
+        
         self.positional_info = positional_info
 
     def identify_positional_value(
         self, args: list[str], command_path: list[str]
     ) -> tuple[str, str] | None:
         """Identify positional value in argument list."""
+        # Guard: Ensure args is not None
+        if args is None:
+            raise ValueError("args cannot be None")
+        
+        # Guard: Ensure command_path is not None
+        if command_path is None:
+            raise ValueError("command_path cannot be None")
         if not command_path:
             return None
 
@@ -49,6 +60,13 @@ class PositionalHandler:
 
     def convert_positional_to_flag(self, param_name: str, param_value: str) -> list[str]:
         """Convert positional parameter to flag format."""
+        # Guard: Ensure param_name is not empty
+        if not param_name or (isinstance(param_name, str) and not param_name.strip()):
+            raise ValueError("param_name cannot be empty")
+        
+        # Guard: Ensure param_value is not None
+        if param_value is None:
+            raise ValueError("param_value cannot be None")
         flag_name = TextUtil.kebab_case(param_name)
         return [f"--{flag_name}", param_value]
 
@@ -56,6 +74,17 @@ class PositionalHandler:
         self, param_name: str, param_value: str, param_type: type
     ) -> tuple[bool, str | None]:
         """Validate positional parameter value matches expected type."""
+        # Guard: Ensure param_name is not empty
+        if not param_name or (isinstance(param_name, str) and not param_name.strip()):
+            raise ValueError("param_name cannot be empty")
+        
+        # Guard: Ensure param_value is not None
+        if param_value is None:
+            raise ValueError("param_value cannot be None")
+        
+        # Guard: Ensure param_type is not None
+        if param_type is None:
+            raise ValueError("param_type cannot be None")
         if param_type == str:
             return True, None
 
@@ -89,6 +118,9 @@ class PositionalHandler:
 
     def generate_positional_usage(self, command_name: str) -> str:
         """Generate usage text showing positional parameter."""
+        # Guard: Ensure command_name is not empty
+        if not command_name or (isinstance(command_name, str) and not command_name.strip()):
+            raise ValueError("command_name cannot be empty")
         if command_name not in self.positional_info:
             return ""
 
@@ -213,11 +245,17 @@ class PositionalHandler:
 
                 # First parameter without default becomes positional
                 if param.default == param.empty:
+                    # Get help text from function docstring
+                    _, param_help = DocStringParser.extract_function_help(function)
+                    help_text = DocStringParser.create_parameter_help(
+                        param_name, param_help, param.annotation, param.default
+                    )
+                    
                     return PositionalInfo(
                         param_name=param_name,
                         param_type=param.annotation if param.annotation != param.empty else str,
                         is_required=True,
-                        help_text=f"{param_name} parameter",
+                        help_text=help_text,
                     )
         except (ValueError, TypeError):
             # Handle cases where signature inspection fails
