@@ -1,6 +1,6 @@
 """Shared data structures and components used across freyja packages."""
 
-from freyja.shared.command_info import CommandInfo
-from freyja.shared.command_tree import CommandTree
+from .command_info import CommandInfo
+from .command_tree import CommandTree
 
 __all__ = ['CommandTree', 'CommandInfo']
