@@ -1,19 +1,28 @@
 """Utility package - common helper functions and classes."""
 
 from .ansi_string import AnsiString
+from .app_logger import AppLogger
+from .console_formatter import ConsoleFormatter
 from .data_struct_util import DataStructUtil
+from .dependency_analyzer import DependencyAnalyzer
+from .json_formatter import JsonFormatter
 from .math_util import MathUtil
-from .output_capture import OutputCapture, OutputFormatter
+from .output_capture import OutputCapture, OutputCaptureConfig, OutputFormatter
 from .spinner import CommandContext, ExecutionSpinner
 from .text_util import TextUtil
 
 __all__ = [
     "AnsiString",
+    "AppLogger",
+    "CommandContext",
+    "ConsoleFormatter",
     "DataStructUtil",
+    "DependencyAnalyzer",
+    "ExecutionSpinner",
+    "JsonFormatter",
     "MathUtil",
     "TextUtil",
-    "ExecutionSpinner",
-    "CommandContext",
     "OutputCapture",
+    "OutputCaptureConfig",
     "OutputFormatter",
 ]
